src.imagedata.apps.Siemens package
==================================

Submodules
----------

src.imagedata.apps.Siemens.ROI module
-------------------------------------

.. automodule:: src.imagedata.apps.Siemens.ROI
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.apps.Siemens.draw\_antialiased module
---------------------------------------------------

.. automodule:: src.imagedata.apps.Siemens.draw_antialiased
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.apps.Siemens.evidence2mask module
-----------------------------------------------

.. automodule:: src.imagedata.apps.Siemens.evidence2mask
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.apps.Siemens.evidence\_main module
------------------------------------------------

.. automodule:: src.imagedata.apps.Siemens.evidence_main
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: src.imagedata.apps.Siemens
   :members:
   :undoc-members:
   :show-inheritance:
